---
name: Bug report
about: Found something wrong? Let us know.
title: "[BUG] "
labels: bug
assignees: ''
---

# Describe the Bug

A clear and concise description of what the bug is.

# To Reproduce

Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

# Expected Behaviour

A clear and concise description of what you expected to happen.
